@@ -2,6 +2,7 @@ import json
 from .util import check_type, unique_string
 from datetime import datetime
 
+
 class classorinstancemethod(classmethod):
 
     def __get__(self, instance, type_):
@@ -9,6 +10,10 @@ class classorinstancemethod(classmethod):
         return descr_get(instance, type_)
 
 
+class JsonDate:
+    date_format = '%Y-%m-%d %H:%M:%S.%f'
+
+
 class JsonObject:
 
     def __init__(self, **kwargs):
@@ -28,7 +33,7 @@ class JsonObject:
             if isinstance(v[k], str):
                 s += "%s" % json.dumps(v[k])
             elif isinstance(v[k], datetime):
-                s += "\"%s\"" % str(v[k])
+                s += "\"%s\"" % v[k].strftime(JsonDate.date_format)
             elif isinstance(v[k], bool):
                 s += "%s" % str(v[k]).lower()
             else:
@@ -50,8 +55,7 @@ class JsonObject:
     def copy(self):
         return type(self).parse(str(self))
 
-    def format(self, format_string):
-        check_type(format_string, str, "wrong type for format_string")
+    def format(self, format_string: str):
         v = vars(self)
         for k in v:
             if not isinstance(v[k], JsonObject):
@@ -74,12 +78,10 @@ class JsonObject:
         return format_string.format(**vars(self))
 
     @classorinstancemethod
-    def parse(cls_or_self, json_string="", json_dictionary=None):
+    def parse(cls_or_self, json_string: str = "", json_dictionary: dict=None):
         if json_string:
-            check_type(json_string, str, "wrong type for json_string")
             json_dictionary = json.loads(json_string)
 
-        check_type(json_dictionary, dict, "wrong type for json_dictionary")
         if type(cls_or_self) is type:
             new_object = cls_or_self()
         else:
@@ -92,13 +94,16 @@ class JsonObject:
                 setattr(new_object, key, av)
             elif issubclass(it, JsonList):
                 member.parse(json_list=json_dictionary[key])
+            elif it is datetime:
+                av = datetime.strptime(json_dictionary[key], JsonDate.date_format)
+                setattr(new_object, key, av)
             else:
                 av = it(json_dictionary[key])
                 setattr(new_object, key, av)
         return new_object
 
     @staticmethod
-    def load(json_string="", json_dictionary_or_list=None) -> type:
+    def load(json_string: str = "", json_dictionary_or_list=None) -> type:
         if json_string:
             check_type(json_string, str, "wrong type for json_string")
             json_dictionary_or_list = json.loads(json_string)
@@ -227,4 +232,4 @@ class JsonList(list):
                 new_list.append(it.parse(json_list=i))
             else:
                 new_list.append(i)
-        return new_list
\ No newline at end of file
+        return new_list
